@@ -29,7 +29,9 @@ use crate::{
 use bytes::{Buf, Bytes};
 use chrono::{DateTime, Utc};
 use percent_encoding::{utf8_percent_encode, PercentEncode};
-use reqwest::{Client as ReqwestClient, Method, Response, StatusCode};
+use reqwest::{
+    header::CONTENT_TYPE, Client as ReqwestClient, Method, Response, StatusCode,
+};
 use serde::{Deserialize, Serialize};
 use snafu::{ResultExt, Snafu};
 use std::ops::Range;
@@ -131,7 +133,7 @@ impl TryFrom<ListResponse> for ListResult {
         let common_prefixes = value
             .common_prefixes
             .into_iter()
-            .map(|x| Ok(Path::parse(&x.prefix)?))
+            .map(|x| Ok(Path::parse(x.prefix)?))
             .collect::<Result<_>>()?;
 
         let objects = value
@@ -187,9 +189,9 @@ struct CompleteMultipart {
 
 #[derive(Debug, Serialize)]
 struct MultipartPart {
-    #[serde(rename = "$unflatten=ETag")]
+    #[serde(rename = "ETag")]
     e_tag: String,
-    #[serde(rename = "$unflatten=PartNumber")]
+    #[serde(rename = "PartNumber")]
     part_number: usize,
 }
 
@@ -279,6 +281,10 @@ impl S3Client {
             builder = builder.body(bytes)
         }
 
+        if let Some(value) = self.config().client_options.get_content_type(path) {
+            builder = builder.header(CONTENT_TYPE, value);
+        }
+
         let response = builder
             .query(query)
             .with_aws_sigv4(credential.as_ref(), &self.config.region, "s3")
